@@ -5,14 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-sam", "1.57.0", __name__[0:-6], "aws-sam@1.57.0.jsii.tgz"
+    "@aws-cdk/aws-sam", "1.67.0", __name__[0:-6], "aws-sam@1.67.0.jsii.tgz"
 )
 
 __all__ = [
